@@ -85,13 +85,13 @@ class InputData:
         if shots is not None and type(shots) != int:
             raise Exception("The 'shots' setting in a PUB must be an integer and be positioned as the third element of a tuple specifying a PUB.")
         if paramaters is not None and type(paramaters) != list:
-            raise Exception("The 'paramaters' in a PUB must be a list of floating point numbers and be positioned as the second element of a tuple specifying a PUB.")
-        if quantum_circuit.num_parameters == 0 and (paramaters is not None or len(paramaters) != 0):
+            raise Exception("The 'paramaters' in a PUB must be a list of numbers and be positioned as the second element of a tuple specifying a PUB.")
+        if quantum_circuit.num_parameters == 0 and (paramaters is not None and len(paramaters) != 0):
             raise Exception("A circuit with zero parameters must have 'paramaters' argument 'None' or an empty list.")
-        elif quantum_circuit.num_parameters != len(paramaters):
+        elif paramaters is not None and quantum_circuit.num_parameters != len(paramaters):
             raise Exception(f"The number of paramaters for a quantum circuit {quantum_circuit.num_parameters} is different from the length {len(paramaters)} of the list of aruguments.")
         if paramaters is not None and not all(isinstance(item, (int, float)) for item in paramaters):
-            raise Exception("The 'paramaters' setting in a PUB must be a list of floating point numbers.")
+            raise Exception("The 'paramaters' setting in a PUB must be a list of numbers.")
 
         return (self.serialize_circuit(quantum_circuit), paramaters, shots)
 
